@@ -49,10 +49,7 @@
 
 package com.openexchange.drive.checksum.rdb;
 
-import static com.openexchange.drive.checksum.rdb.SQL.escapeFile;
-import static com.openexchange.drive.checksum.rdb.SQL.escapeFolder;
-import static com.openexchange.drive.checksum.rdb.SQL.unescapeFile;
-import static com.openexchange.drive.checksum.rdb.SQL.unescapeFolder;
+import static com.openexchange.drive.checksum.rdb.SQL.*;
 import static com.openexchange.java.Strings.reverse;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
@@ -426,6 +423,37 @@ public class RdbChecksumStore implements ChecksumStore {
         }
     }
 
+    @Override
+    public int touchDirectoryChecksums(List<DirectoryChecksum> directoryChecksums) throws OXException {
+        Connection connection = databaseService.getWritable(contextID);
+        try {
+            int touched = 0;
+            for (int i = 0; i < directoryChecksums.size(); i += INSERT_CHUNK_SIZE) {
+                /*
+                 * prepare chunk
+                 */
+                int length = Math.min(directoryChecksums.size(), i + INSERT_CHUNK_SIZE) - i;
+                String[] uuids = new String[length];
+                for (int j = 0; j < length; j++) {
+                    String uuid = directoryChecksums.get(i + j).getUuid();
+                    if (null == uuid) {
+                        throw new IllegalArgumentException("Touching directory checksums requires an existing UUID");
+                    }
+                    uuids[j] = uuid;
+                }
+                /*
+                 * touch chunk
+                 */
+                touched += touchDirectoryChecksums(connection, contextID, uuids);
+            }
+            return touched;
+        } catch (SQLException e) {
+            throw DriveExceptionCodes.DB_ERROR.create(e, e.getMessage());
+        } finally {
+            databaseService.backWritable(contextID, connection);
+        }
+    }
+
     private static String newUid() {
         return UUIDs.getUnformattedString(UUID.randomUUID());
     }
@@ -646,6 +674,7 @@ public class RdbChecksumStore implements ChecksumStore {
             stmt.setLong(6, directoryChecksum.getSequenceNumber());
             stmt.setString(7, directoryChecksum.getETag());
             stmt.setString(8, directoryChecksum.getChecksum());
+            stmt.setLong(9, System.currentTimeMillis());
             return SQL.logExecuteUpdate(stmt);
         } finally {
             DBUtils.closeSQLStuff(stmt);
@@ -660,8 +689,9 @@ public class RdbChecksumStore implements ChecksumStore {
             stmt.setLong(2, directoryChecksum.getSequenceNumber());
             stmt.setString(3, directoryChecksum.getETag());
             stmt.setString(4, directoryChecksum.getChecksum());
-            stmt.setInt(5, cid);
-            stmt.setString(6, directoryChecksum.getUuid());
+            stmt.setLong(5, System.currentTimeMillis());
+            stmt.setInt(6, cid);
+            stmt.setString(7, directoryChecksum.getUuid());
             return SQL.logExecuteUpdate(stmt);
         } finally {
             DBUtils.closeSQLStuff(stmt);
@@ -673,8 +703,9 @@ public class RdbChecksumStore implements ChecksumStore {
         try {
             stmt = connection.prepareStatement(SQL.UPDATE_DIRECTORY_CHECKSUM_FOLDER_STMT);
             stmt.setString(1, escapeFolder(newFolder));
-            stmt.setInt(2, cid);
-            stmt.setString(3, escapeFolder(folder));
+            stmt.setLong(2, System.currentTimeMillis());
+            stmt.setInt(3, cid);
+            stmt.setString(4, escapeFolder(folder));
             return SQL.logExecuteUpdate(stmt);
         } finally {
             DBUtils.closeSQLStuff(stmt);
@@ -703,10 +734,10 @@ public class RdbChecksumStore implements ChecksumStore {
             int parameterIndex = 1;
             stmt.setInt(parameterIndex++, cid);
             stmt.setInt(parameterIndex++, user);
+            stmt.setInt(parameterIndex++, view);
             for (int i = 0; i < folderIDs.length; i++) {
                 stmt.setString(parameterIndex++, reverse(escapeFolder(folderIDs[i])));
             }
-            stmt.setInt(parameterIndex++, view);
             ResultSet resultSet = SQL.logExecuteQuery(stmt);
             while (resultSet.next()) {
                 DirectoryChecksum directoryChecksum = new DirectoryChecksum();
@@ -725,5 +756,20 @@ public class RdbChecksumStore implements ChecksumStore {
         return directoryChecksums;
     }
 
+    private static int touchDirectoryChecksums(Connection connection, int cid, String[] uuids) throws SQLException {
+        PreparedStatement stmt = null;
+        try {
+            stmt = connection.prepareStatement(SQL.TOUCH_DIRECTORY_CHECKSUMS_STMT(uuids.length));
+            stmt.setLong(1, System.currentTimeMillis());
+            stmt.setInt(2, cid);
+            for (int i = 0; i < uuids.length; i++) {
+                stmt.setBytes(i + 3, SQL.getBytes(uuids[i]));
+            }
+            return SQL.logExecuteUpdate(stmt);
+        } finally {
+            DBUtils.closeSQLStuff(stmt);
+        }
+    }
+
 }
 
