@@ -163,25 +163,6 @@ public class DriveConstants {
      */
     public static final Pattern CHECKSUM_VALIDATION_PATTERN = Pattern.compile("^[0-9a-f]{32}\\z");
 
-    /**
-     * Pattern to match valid (Windows-) filenames, borrowed from http://stackoverflow.com/questions/6730009 , based on
-     * http://msdn.microsoft.com/en-us/library/aa365247%28v=vs.85%29.aspx#file_and_directory_names
-     */
-    public static final Pattern FILENAME_VALIDATION_PATTERN = Pattern.compile(
-        "^                                # Anchor to start of string.        \n" +
-        "(?!                              # Assert filename is not: CON, PRN, \n" +
-        "  (?:                            # AUX, NUL, COM1, COM2, COM3, COM4, \n" +
-        "    CON|PRN|AUX|NUL|             # COM5, COM6, COM7, COM8, COM9,     \n" +
-        "    COM[1-9]|LPT[1-9]            # LPT1, LPT2, LPT3, LPT4, LPT5,     \n" +
-        "  )                              # LPT6, LPT7, LPT8, and LPT9...     \n" +
-        "  (?:\\.[^.]*)?                  # followed by optional extension    \n" +
-        "  $                              # and end of string                 \n" +
-        ")                                # End negative lookahead assertion. \n" +
-        "[^<>:/?*\"\\\\|\\x00-\\x1F]*     # Zero or more valid filename chars.\n" +
-        "[^<>:/?*\"\\\\|\\x00-\\x1F\\ .]  # Last char is not a space or dot.  \n" +
-        "$                                # Anchor to end of string.            ",
-        Pattern.CASE_INSENSITIVE | Pattern.UNICODE_CASE | Pattern.COMMENTS);
-
     /**
      * Pattern to match valid path names as used by the drive module, based on
      * http://msdn.microsoft.com/en-us/library/aa365247%28v=vs.85%29.aspx#file_and_directory_names
